
The documentation of Plumbery
=============================

.. toctree::
   :maxdepth: 2

   readme
   getting_started
   usage
   tutorials
   contributing
   coding
   history
   Documentation extracted from the code <plumbery>


* :ref:`genindex`

